@@ -1,5 +1,5 @@
 package Data::AMF::Header;
-use Moose;
+use Any::Moose;
 
 has name => (
     is       => 'rw',
@@ -22,6 +22,12 @@ has version => (
     isa => 'Int',
 );
 
+no Any::Moose;
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
 =head1 NAME
 
 Data::AMF::Header - AMF message header
@@ -49,7 +55,3 @@ The full text of the license can be found in the
 LICENSE file included with this module.
 
 =cut
-
-1;
-
-
